==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_entities/binstock_001/BinStock.java <==

package net.datastream.schemas.mp_entities.binstock_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.PARTID_Type;
import net.datastream.schemas.mp_fields.STOREID_Type;
import net.datastream.schemas.mp_fields.StandardUserDefinedFields;
import net.datastream.schemas.mp_fields.UOMID_Type;
import org.openapplications.oagis_segments.AMOUNT;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STOREID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BIN" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PRICE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}QTYONHAND" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BYASSET" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REPAIRQTY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UOMID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTCONDITIONTEMPLATECONDITIONCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INSTALLEDCOMPONENT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}StandardUserDefinedFields" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *       &lt;attribute name="user_entity" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="system_entity" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "partid",
    "storeid",
    "bin",
    "lot",
    "price",
    "qtyonhand",
    "byasset",
    "repairqty",
    "uomid",
    "partconditiontemplateconditioncode",
    "installedcomponent",
    "standardUserDefinedFields"
})
@XmlRootElement(name = "BinStock")
public class BinStock {

    @XmlElement(name = "PARTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected PARTID_Type partid;
    @XmlElement(name = "STOREID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected STOREID_Type storeid;
    @XmlElement(name = "BIN", namespace = "http://schemas.datastream.net/MP_fields")
    protected String bin;
    @XmlElement(name = "LOT", namespace = "http://schemas.datastream.net/MP_fields")
    protected String lot;
    @XmlElement(name = "PRICE", namespace = "http://schemas.datastream.net/MP_fields")
    protected AMOUNT price;
    @XmlElement(name = "QTYONHAND", namespace = "http://schemas.datastream.net/MP_fields")
    protected AMOUNT qtyonhand;
    @XmlElement(name = "BYASSET", namespace = "http://schemas.datastream.net/MP_fields")
    protected String byasset;
    @XmlElement(name = "REPAIRQTY", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY repairqty;
    @XmlElement(name = "UOMID", namespace = "http://schemas.datastream.net/MP_fields")
    protected UOMID_Type uomid;
    @XmlElement(name = "PARTCONDITIONTEMPLATECONDITIONCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String partconditiontemplateconditioncode;
    @XmlElement(name = "INSTALLEDCOMPONENT", namespace = "http://schemas.datastream.net/MP_fields")
    protected String installedcomponent;
    @XmlElement(name = "StandardUserDefinedFields", namespace = "http://schemas.datastream.net/MP_fields")
    protected StandardUserDefinedFields standardUserDefinedFields;
    @XmlAttribute(name = "recordid")
    protected Long recordid;
    @XmlAttribute(name = "user_entity")
    protected String user_Entity;
    @XmlAttribute(name = "system_entity")
    protected String system_Entity;

    /**
     * Obtient la valeur de la propriété partid.
     * 
     * @return
     *     possible object is
     *     {@link PARTID_Type }
     *     
     */
    public PARTID_Type getPARTID() {
        return partid;
    }

    /**
     * Définit la valeur de la propriété partid.
     * 
     * @param value
     *     allowed object is
     *     {@link PARTID_Type }
     *     
     */
    public void setPARTID(PARTID_Type value) {
        this.partid = value;
    }

    /**
     * Obtient la valeur de la propriété storeid.
     * 
     * @return
     *     possible object is
     *     {@link STOREID_Type }
     *     
     */
    public STOREID_Type getSTOREID() {
        return storeid;
    }

    /**
     * Définit la valeur de la propriété storeid.
     * 
     * @param value
     *     allowed object is
     *     {@link STOREID_Type }
     *     
     */
    public void setSTOREID(STOREID_Type value) {
        this.storeid = value;
    }

    /**
     * Obtient la valeur de la propriété bin.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBIN() {
        return bin;
    }

    /**
     * Définit la valeur de la propriété bin.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBIN(String value) {
        this.bin = value;
    }

    /**
     * Obtient la valeur de la propriété lot.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLOT() {
        return lot;
    }

    /**
     * Définit la valeur de la propriété lot.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLOT(String value) {
        this.lot = value;
    }

    /**
     * Obtient la valeur de la propriété price.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getPRICE() {
        return price;
    }

    /**
     * Définit la valeur de la propriété price.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setPRICE(AMOUNT value) {
        this.price = value;
    }

    /**
     * Obtient la valeur de la propriété qtyonhand.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getQTYONHAND() {
        return qtyonhand;
    }

    /**
     * Définit la valeur de la propriété qtyonhand.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setQTYONHAND(AMOUNT value) {
        this.qtyonhand = value;
    }

    /**
     * Obtient la valeur de la propriété byasset.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBYASSET() {
        return byasset;
    }

    /**
     * Définit la valeur de la propriété byasset.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBYASSET(String value) {
        this.byasset = value;
    }

    /**
     * Obtient la valeur de la propriété repairqty.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getREPAIRQTY() {
        return repairqty;
    }

    /**
     * Définit la valeur de la propriété repairqty.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setREPAIRQTY(QUANTITY value) {
        this.repairqty = value;
    }

    /**
     * Obtient la valeur de la propriété uomid.
     * 
     * @return
     *     possible object is
     *     {@link UOMID_Type }
     *     
     */
    public UOMID_Type getUOMID() {
        return uomid;
    }

    /**
     * Définit la valeur de la propriété uomid.
     * 
     * @param value
     *     allowed object is
     *     {@link UOMID_Type }
     *     
     */
    public void setUOMID(UOMID_Type value) {
        this.uomid = value;
    }

    /**
     * Obtient la valeur de la propriété partconditiontemplateconditioncode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPARTCONDITIONTEMPLATECONDITIONCODE() {
        return partconditiontemplateconditioncode;
    }

    /**
     * Définit la valeur de la propriété partconditiontemplateconditioncode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPARTCONDITIONTEMPLATECONDITIONCODE(String value) {
        this.partconditiontemplateconditioncode = value;
    }

    /**
     * Obtient la valeur de la propriété installedcomponent.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getINSTALLEDCOMPONENT() {
        return installedcomponent;
    }

    /**
     * Définit la valeur de la propriété installedcomponent.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setINSTALLEDCOMPONENT(String value) {
        this.installedcomponent = value;
    }

    /**
     * Obtient la valeur de la propriété standardUserDefinedFields.
     * 
     * @return
     *     possible object is
     *     {@link StandardUserDefinedFields }
     *     
     */
    public StandardUserDefinedFields getStandardUserDefinedFields() {
        return standardUserDefinedFields;
    }

    /**
     * Définit la valeur de la propriété standardUserDefinedFields.
     * 
     * @param value
     *     allowed object is
     *     {@link StandardUserDefinedFields }
     *     
     */
    public void setStandardUserDefinedFields(StandardUserDefinedFields value) {
        this.standardUserDefinedFields = value;
    }

    /**
     * Obtient la valeur de la propriété recordid.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Définit la valeur de la propriété recordid.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

    /**
     * Obtient la valeur de la propriété user_Entity.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUser_Entity() {
        return user_Entity;
    }

    /**
     * Définit la valeur de la propriété user_Entity.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUser_Entity(String value) {
        this.user_Entity = value;
    }

    /**
     * Obtient la valeur de la propriété system_Entity.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSystem_Entity() {
        return system_Entity;
    }

    /**
     * Définit la valeur de la propriété system_Entity.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSystem_Entity(String value) {
        this.system_Entity = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_entities/binstock_001/BinStock.java <==

package net.datastream.schemas.mp_entities.binstock_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.PARTID_Type;
import net.datastream.schemas.mp_fields.STOREID_Type;
import net.datastream.schemas.mp_fields.StandardUserDefinedFields;
import net.datastream.schemas.mp_fields.UOMID_Type;
import org.openapplications.oagis_segments.AMOUNT;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STOREID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BIN" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PRICE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}QTYONHAND" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BYASSET" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REPAIRQTY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UOMID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTCONDITIONTEMPLATECONDITIONCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INSTALLEDCOMPONENT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}AVAILABLEQUANTITY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}StandardUserDefinedFields" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *       &lt;attribute name="user_entity" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="system_entity" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "partid",
    "storeid",
    "bin",
    "lot",
    "price",
    "qtyonhand",
    "byasset",
    "repairqty",
    "uomid",
    "partconditiontemplateconditioncode",
    "installedcomponent",
    "availablequantity",
    "standardUserDefinedFields"
})
@XmlRootElement(name = "BinStock")
public class BinStock {

    @XmlElement(name = "PARTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected PARTID_Type partid;
    @XmlElement(name = "STOREID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected STOREID_Type storeid;
    @XmlElement(name = "BIN", namespace = "http://schemas.datastream.net/MP_fields")
    protected String bin;
    @XmlElement(name = "LOT", namespace = "http://schemas.datastream.net/MP_fields")
    protected String lot;
    @XmlElement(name = "PRICE", namespace = "http://schemas.datastream.net/MP_fields")
    protected AMOUNT price;
    @XmlElement(name = "QTYONHAND", namespace = "http://schemas.datastream.net/MP_fields")
    protected AMOUNT qtyonhand;
    @XmlElement(name = "BYASSET", namespace = "http://schemas.datastream.net/MP_fields")
    protected String byasset;
    @XmlElement(name = "REPAIRQTY", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY repairqty;
    @XmlElement(name = "UOMID", namespace = "http://schemas.datastream.net/MP_fields")
    protected UOMID_Type uomid;
    @XmlElement(name = "PARTCONDITIONTEMPLATECONDITIONCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String partconditiontemplateconditioncode;
    @XmlElement(name = "INSTALLEDCOMPONENT", namespace = "http://schemas.datastream.net/MP_fields")
    protected String installedcomponent;
    @XmlElement(name = "AVAILABLEQUANTITY", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY availablequantity;
    @XmlElement(name = "StandardUserDefinedFields", namespace = "http://schemas.datastream.net/MP_fields")
    protected StandardUserDefinedFields standardUserDefinedFields;
    @XmlAttribute(name = "recordid")
    protected Long recordid;
    @XmlAttribute(name = "user_entity")
    protected String user_Entity;
    @XmlAttribute(name = "system_entity")
    protected String system_Entity;

    /**
     * Gets the value of the partid property.
     * 
     * @return
     *     possible object is
     *     {@link PARTID_Type }
     *     
     */
    public PARTID_Type getPARTID() {
        return partid;
    }

    /**
     * Sets the value of the partid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PARTID_Type }
     *     
     */
    public void setPARTID(PARTID_Type value) {
        this.partid = value;
    }

    /**
     * Gets the value of the storeid property.
     * 
     * @return
     *     possible object is
     *     {@link STOREID_Type }
     *     
     */
    public STOREID_Type getSTOREID() {
        return storeid;
    }

    /**
     * Sets the value of the storeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STOREID_Type }
     *     
     */
    public void setSTOREID(STOREID_Type value) {
        this.storeid = value;
    }

    /**
     * Gets the value of the bin property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBIN() {
        return bin;
    }

    /**
     * Sets the value of the bin property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBIN(String value) {
        this.bin = value;
    }

    /**
     * Gets the value of the lot property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLOT() {
        return lot;
    }

    /**
     * Sets the value of the lot property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLOT(String value) {
        this.lot = value;
    }

    /**
     * Gets the value of the price property.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getPRICE() {
        return price;
    }

    /**
     * Sets the value of the price property.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setPRICE(AMOUNT value) {
        this.price = value;
    }

    /**
     * Gets the value of the qtyonhand property.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getQTYONHAND() {
        return qtyonhand;
    }

    /**
     * Sets the value of the qtyonhand property.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setQTYONHAND(AMOUNT value) {
        this.qtyonhand = value;
    }

    /**
     * Gets the value of the byasset property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBYASSET() {
        return byasset;
    }

    /**
     * Sets the value of the byasset property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBYASSET(String value) {
        this.byasset = value;
    }

    /**
     * Gets the value of the repairqty property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getREPAIRQTY() {
        return repairqty;
    }

    /**
     * Sets the value of the repairqty property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setREPAIRQTY(QUANTITY value) {
        this.repairqty = value;
    }

    /**
     * Gets the value of the uomid property.
     * 
     * @return
     *     possible object is
     *     {@link UOMID_Type }
     *     
     */
    public UOMID_Type getUOMID() {
        return uomid;
    }

    /**
     * Sets the value of the uomid property.
     * 
     * @param value
     *     allowed object is
     *     {@link UOMID_Type }
     *     
     */
    public void setUOMID(UOMID_Type value) {
        this.uomid = value;
    }

    /**
     * Gets the value of the partconditiontemplateconditioncode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPARTCONDITIONTEMPLATECONDITIONCODE() {
        return partconditiontemplateconditioncode;
    }

    /**
     * Sets the value of the partconditiontemplateconditioncode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPARTCONDITIONTEMPLATECONDITIONCODE(String value) {
        this.partconditiontemplateconditioncode = value;
    }

    /**
     * Gets the value of the installedcomponent property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getINSTALLEDCOMPONENT() {
        return installedcomponent;
    }

    /**
     * Sets the value of the installedcomponent property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setINSTALLEDCOMPONENT(String value) {
        this.installedcomponent = value;
    }

    /**
     * Gets the value of the availablequantity property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getAVAILABLEQUANTITY() {
        return availablequantity;
    }

    /**
     * Sets the value of the availablequantity property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setAVAILABLEQUANTITY(QUANTITY value) {
        this.availablequantity = value;
    }

    /**
     * Gets the value of the standardUserDefinedFields property.
     * 
     * @return
     *     possible object is
     *     {@link StandardUserDefinedFields }
     *     
     */
    public StandardUserDefinedFields getStandardUserDefinedFields() {
        return standardUserDefinedFields;
    }

    /**
     * Sets the value of the standardUserDefinedFields property.
     * 
     * @param value
     *     allowed object is
     *     {@link StandardUserDefinedFields }
     *     
     */
    public void setStandardUserDefinedFields(StandardUserDefinedFields value) {
        this.standardUserDefinedFields = value;
    }

    /**
     * Gets the value of the recordid property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Sets the value of the recordid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

    /**
     * Gets the value of the user_Entity property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUser_Entity() {
        return user_Entity;
    }

    /**
     * Sets the value of the user_Entity property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUser_Entity(String value) {
        this.user_Entity = value;
    }

    /**
     * Gets the value of the system_Entity property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSystem_Entity() {
        return system_Entity;
    }

    /**
     * Sets the value of the system_Entity property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSystem_Entity(String value) {
        this.system_Entity = value;
    }

}
